import { Router } from "vue-router";
import store from "@/store";
import dayjs from "dayjs";
import { Toast } from "vant";
import { useLogin } from "@/hooks";

const guard = (router: Router) => {
  router.beforeEach(async (to, from, next) => {
    if (to.query.state === "LOGIN") {
      const toast = Toast.loading({
        duration: 0, // 持续展示 toast
        forbidClick: true,
        message: "登陆中",
      });
      await useLogin(to.query);
      toast.message = `登陆成功`;
      Toast.clear();
    }

    if (store.getters.getToken === "") {
      location.replace(
        `https://open.weixin.qq.com/connect/oauth2/authorize?appid=wx67ca1b8c9816ef28&redirect_uri=${location.href}&response_type=code&scope=snsapi_userinfo&state=LOGIN#wechat_redirect`
      );
    }

    const userTime = dayjs(store.getters.getUserData.expireTime).valueOf();
    const currentTime = dayjs().valueOf();
    switch (to.path) {
      case "/exercise":
        if (userTime - currentTime > 0) {
          next();
        } else {
          Toast.fail("会员到期");
        }
        break;
      case "/mockTest":
        if (userTime - currentTime > 0) {
          next();
        } else {
          Toast.fail("会员到期");
        }
        break;
      default:
        next();
        break;
    }
  });
};
export default guard;
